# The idiomatic asyncio MQTT client 🙌

```{include} ../README.md
:start-after: <!-- documentation start -->
```

```{toctree}
:hidden:

introduction
```

```{toctree}
:caption: Guides
:hidden:

connecting-to-the-broker
publishing-a-message
subscribing-to-a-topic
reconnection
alongside-fastapi-and-co
```

```{toctree}
:caption: reference
:hidden:

developer-interface
migration-guide-v2
```

```{toctree}
:caption: Project links
:hidden:

GitHub <https://github.com/empicano/aiomqtt>
Issue tracker <https://github.com/empicano/aiomqtt/issues>
Changelog <https://github.com/empicano/aiomqtt/blob/main/CHANGELOG.md>
Contributing <https://github.com/empicano/aiomqtt/blob/main/CONTRIBUTING.md>
PyPI <https://pypi.org/project/aiomqtt/>
```
